%define glib2_base_version 2.28.0
%define glib2_version %{glib2_base_version}-1
%define pango_base_version 1.20.0
%define pango_version %{pango_base_version}-1
%define atk_base_version 1.29.4
%define atk_version %{atk_base_version}-2
%define cairo_base_version 1.6.0
%define cairo_version %{cairo_base_version}-1
%define xrandr_version 1.2.99.4-2
%define gobject_introspection_version 0.9.3
%define gir_repository_version 0.6.5-5
%define bin_version 2.10.0

%global __provides_exclude_from ^%{_libdir}/gtk-2.0

Summary:  GTK+ graphical user interface library
Name:     gtk2
Version:  2.24.33
Release:  1%{?dist}
License:  LGPLv2+
URL:      http://www.gtk.org
Source0:  http://download.gnome.org/sources/gtk+/2.24/gtk+-%{version}.tar.xz
Source1:  update-gtk-immodules
Source2:  im-cedilla.conf
Source3:  update-gtk-immodules.1
Patch3000: icon-padding.patch
Patch3001: tooltip-positioning.patch
Patch3002: window-dragging.patch
Patch3003: gtk2-c99.patch

BuildRequires: pkgconfig(atk) >= %{atk_version}, pkgconfig(glib-2.0) >= %{glib2_version}
BuildRequires: pkgconfig(gobject-introspection-1.0) >= %{gobject_introspection_version}
BuildRequires: pkgconfig(cairo), pkgconfig(gdk-pixbuf-2.0), pkgconfig(pango) >= %{pango_version}
BuildRequires: pkgconfig(xi), pkgconfig(xrandr), pkgconfig(xrender), pkgconfig(xcursor)
BuildRequires: pkgconfig(xfixes), pkgconfig(xinerama), pkgconfig(xcomposite), pkgconfig(xdamage)
BuildRequires: gettext, make, automake, autoconf, pkgconfig, libtool
BuildRequires: cups-devel, python3-devel, gtk-doc

Provides: gail = %{version}-%{release}

Requires: hicolor-icon-theme
Requires: gtk-update-icon-cache
Requires: gdk-pixbuf2-modules%{?_isa}
Requires: glib2 >= %{glib2_version}
Requires: atk >= %{atk_version}
Requires: pango >= %{pango_version}
Requires(post): libtiff >= 3.6.1
Requires: libXrandr >= %{xrandr_version}

Recommends: (adwaita-gtk2-theme if gnome-shell)
Recommends: libcanberra-gtk2%{?_isa}
Recommends: (ibus-gtk2 if ibus)

%description
GTK+ is a multi-platform toolkit for creating graphical user
interfaces. Offering a complete set of widgets, GTK+ is suitable for
projects ranging from small one-off tools to complete application
suites.

%package immodules
Summary: Input methods for GTK+
Requires: gtk2 = %{version}-%{release}
Requires: gtk-immodules-imsettings

%description immodules
The gtk2-immodules package contains standalone input methods that are shipped
as part of GTK+.

%package -n gtk-immodules-imsettings
Summary: IMSettings config files for GTK+ input methods
BuildArch: noarch

%description -n gtk-immodules-imsettings
The gtk-immodules-imsettings package contains IMSettings configuration for the
standalone input methods that are shipped as part of GTK+.

%package immodule-xim
Summary: XIM support for GTK+
Requires: gtk2 = %{version}-%{release}

%description immodule-xim
The gtk2-immodule-xim package contains XIM support for GTK+.

%package devel
Summary: Development files for GTK+
Requires: gtk2 = %{version}-%{release}
Requires: pango-devel >= %{pango_version}
Requires: atk-devel >= %{atk_version}
Requires: glib2-devel >= %{glib2_version}
Requires: gdk-pixbuf2-devel
Requires: cairo-devel >= %{cairo_version}
Requires: libX11-devel, libXcursor-devel, libXinerama-devel
Requires: libXext-devel, libXi-devel, libXrandr-devel
Requires: libXfixes-devel, libXcomposite-devel
Requires: pkgconfig
Provides: gail-devel = %{version}-%{release}

%description devel
This package contains the libraries and header files that are needed
for writing applications with the GTK+ widget toolkit. If you plan
to develop applications with GTK+, consider installing the gtk2-devel-docs
package.

%package devel-docs
Summary: Developer documentation for GTK+
Requires: gtk2 = %{version}-%{release}

%description devel-docs
This package contains developer documentation for the GTK+ widget toolkit.



%prep
%autosetup -n gtk+-%{version} -p1



%build
export CFLAGS='-fno-strict-aliasing %optflags'
(if ! test -x configure; then NOCONFIGURE=1 ./autogen.sh; CONFIGFLAGS=--enable-gtk-doc; fi;
 %configure $CONFIGFLAGS \
	--enable-man		\
	--with-xinput=xfree	\
	--enable-debug		\
)

sed -i -e 's/ -shared / -Wl,-O1,--as-needed\0/g' libtool

make %{?_smp_mflags}

awk '/^Overview of Changes/ { seen+=1 }
{ if (seen < 2) print }
{ if (seen == 2) { print "For older news, see http://git.gnome.org/cgit/gtk+/plain/NEWS"; exit } }' NEWS > tmp; mv tmp NEWS



%install
case "%{_host}" in
  *linux) host="%{_host}-gnu"
  ;;
  *) host="%{_host}"
  ;;
esac

host=`echo $host | sed "s/^ppc/powerpc/"`

compile_host=`grep 'host_triplet =' gtk/Makefile | sed "s/.* = //"`

if test "x$compile_host" != "x$host" ; then
  echo 1>&2 "Host mismatch: compile='$compile_host', spec file='$host'" && exit 1
fi

make install DESTDIR=%{buildroot}        \
             RUN_QUERY_IMMODULES_TEST=false

echo ".so man1/gtk-query-immodules-2.0.1" > %{buildroot}%{_mandir}/man1/gtk-query-immodules-2.0-%{__isa_bits}.1

gzip -c %{SOURCE3} > %{buildroot}%{_mandir}/man1/update-gtk-immodules.1.gz

%find_lang gtk20
%find_lang gtk20-properties

mkdir -p tmpdocs

for dir in examples/* ; do
  if [ -d $dir ] ; then
     mkdir -p tmpdocs/$dir
     for file in $dir/* ; do
       install -m 0644 $file tmpdocs/$dir
     done
  fi
done

case "$host" in
  alpha*|ia64*|ppc64*|powerpc64*|s390x*|x86_64*|aarch64*|mips64*|loongarch64*|sw_64*|riscv64*)
   mv %{buildroot}%{_bindir}/gtk-query-immodules-2.0 %{buildroot}%{_bindir}/gtk-query-immodules-2.0-64
   ;;
  *)
   mv %{buildroot}%{_bindir}/gtk-query-immodules-2.0 %{buildroot}%{_bindir}/gtk-query-immodules-2.0-32
   ;;
esac

cp %{SOURCE1} %{buildroot}%{_bindir}/update-gtk-immodules

mkdir -p %{buildroot}%{_sysconfdir}/X11/xinit/xinput.d
cp %{SOURCE2} %{buildroot}%{_sysconfdir}/X11/xinit/xinput.d

%{__python3} /usr/bin/pathfix.py -pn -i %{__python3} %{buildroot}%{_bindir}/gtk-builder-convert

rm %{buildroot}%{_libdir}/*.la
rm %{buildroot}%{_libdir}/gtk-2.0/*/*.la
rm %{buildroot}%{_libdir}/gtk-2.0/%{bin_version}/*/*.la
rm %{buildroot}%{_bindir}/gtk-update-icon-cache
rm %{buildroot}%{_mandir}/man1/gtk-update-icon-cache.1*

touch %{buildroot}%{_libdir}/gtk-2.0/%{bin_version}/immodules.cache

mkdir -p %{buildroot}%{_libdir}/gtk-2.0/modules
mkdir -p %{buildroot}%{_libdir}/gtk-2.0/immodules
mkdir -p %{buildroot}%{_libdir}/gtk-2.0/%{bin_version}/filesystems


%transfiletriggerin -- %{_libdir}/gtk-2.0/immodules/ %{_libdir}/gtk-2.0/%{bin_version}/immodules/
gtk-query-immodules-2.0-%{__isa_bits} --update-cache

%transfiletriggerpostun -- %{_libdir}/gtk-2.0/immodules/ %{_libdir}/gtk-2.0/%{bin_version}/immodules/
gtk-query-immodules-2.0-%{__isa_bits} --update-cache



%files -f gtk20.lang
%license COPYING
%doc AUTHORS NEWS README
%{_bindir}/gtk-query-immodules-2.0*
%{_bindir}/update-gtk-immodules
%{_libdir}/libgtk-x11-2.0.so.*
%{_libdir}/libgdk-x11-2.0.so.*
%{_libdir}/libgailutil.so.*
%dir %{_libdir}/gtk-2.0
%dir %{_libdir}/gtk-2.0/%{bin_version}
%{_libdir}/gtk-2.0/%{bin_version}/engines
%{_libdir}/gtk-2.0/%{bin_version}/filesystems
%dir %{_libdir}/gtk-2.0/%{bin_version}/immodules
%{_libdir}/gtk-2.0/%{bin_version}/printbackends
%{_libdir}/gtk-2.0/modules
%{_libdir}/gtk-2.0/immodules
%dir %{_datadir}/gtk-2.0
%{_datadir}/themes/Default
%{_datadir}/themes/Emacs
%{_datadir}/themes/Raleigh
%ghost %{_libdir}/gtk-2.0/%{bin_version}/immodules.cache
%{_libdir}/girepository-1.0
%{_mandir}/man1/gtk-query-immodules-2.0*
%{_mandir}/man1/update-gtk-immodules.1*

%files immodules
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-am-et.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-cedilla.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-cyrillic-translit.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-inuktitut.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-ipa.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-multipress.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-thai.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-ti-er.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-ti-et.so
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-viqr.so
%dir %{_sysconfdir}/gtk-2.0
%config(noreplace) %{_sysconfdir}/gtk-2.0/im-multipress.conf

%files -n gtk-immodules-imsettings
%{_sysconfdir}/X11/xinit/xinput.d/im-cedilla.conf

%files immodule-xim
%{_libdir}/gtk-2.0/%{bin_version}/immodules/im-xim.so

%files devel -f gtk20-properties.lang
%{_libdir}/lib*.so
%{_libdir}/gtk-2.0/include
%{_includedir}/*
%{_datadir}/aclocal/*
%{_bindir}/gtk-builder-convert
%{_libdir}/pkgconfig/*
%{_bindir}/gtk-demo
%{_datadir}/gtk-2.0/demo
%{_datadir}/gir-1.0
%{_mandir}/man1/gtk-builder-convert.1*

%files devel-docs
%{_datadir}/gtk-doc
%doc tmpdocs/examples



%changelog
* Tue Dec 26 2023 Zhao Zhen <jeremiazhao@tencent.com> - 2.24.33-1
- initial